@@ -151,6 +151,7 @@ tb_int_t xm_os_cpuinfo(lua_State *lua);
 tb_int_t xm_os_meminfo(lua_State *lua);
 tb_int_t xm_os_readlink(lua_State *lua);
 tb_int_t xm_os_filesize(lua_State *lua);
+tb_int_t xm_os_access(lua_State *lua);
 tb_int_t xm_os_emptydir(lua_State *lua);
 tb_int_t xm_os_syserror(lua_State *lua);
 tb_int_t xm_os_strerror(lua_State *lua);
@@ -174,6 +175,7 @@ tb_int_t xm_io_file_rawfd(lua_State *lua);
 tb_int_t xm_io_file_write(lua_State *lua);
 tb_int_t xm_io_file_flush(lua_State *lua);
 tb_int_t xm_io_file_close(lua_State *lua);
+tb_int_t xm_io_file_convert(lua_State *lua);
 tb_int_t xm_io_file_isatty(lua_State *lua);
 
 // the io/filelock functions
@@ -276,8 +278,23 @@ tb_int_t xm_winos_registry_query(lua_State *lua);
 tb_int_t xm_winos_registry_keys(lua_State *lua);
 tb_int_t xm_winos_registry_values(lua_State *lua);
 tb_int_t xm_winos_short_path(lua_State *lua);
+tb_int_t xm_winos_processes(lua_State* lua);
+tb_int_t xm_winos_set_error_mode(lua_State *lua);
 #endif
 
+// the utf8 functions
+tb_int_t xm_utf8_len(lua_State *lua);
+tb_int_t xm_utf8_char(lua_State *lua);
+tb_int_t xm_utf8_byte(lua_State *lua);
+tb_int_t xm_utf8_codepoint(lua_State *lua);
+tb_int_t xm_utf8_offset(lua_State *lua);
+tb_int_t xm_utf8_codes(lua_State *lua);
+tb_int_t xm_utf8_sub(lua_State *lua);
+tb_int_t xm_utf8_reverse(lua_State *lua);
+tb_int_t xm_utf8_lastof(lua_State *lua);
+tb_int_t xm_utf8_find(lua_State *lua);
+tb_int_t xm_utf8_width(lua_State *lua);
+
 // the string functions
 tb_int_t xm_string_trim(lua_State *lua);
 tb_int_t xm_string_split(lua_State *lua);
@@ -285,6 +302,8 @@ tb_int_t xm_string_lastof(lua_State *lua);
 tb_int_t xm_string_convert(lua_State *lua);
 tb_int_t xm_string_endswith(lua_State *lua);
 tb_int_t xm_string_startswith(lua_State *lua);
+tb_int_t xm_string_lower(lua_State *lua);
+tb_int_t xm_string_upper(lua_State *lua);
 
 // the process functions
 tb_int_t xm_process_open(lua_State *lua);
@@ -345,6 +364,7 @@ tb_int_t xm_binutils_deplibs(lua_State *lua);
 tb_int_t xm_binutils_rpath_list(lua_State *lua);
 tb_int_t xm_binutils_rpath_clean(lua_State *lua);
 tb_int_t xm_binutils_extractlib(lua_State *lua);
+tb_int_t xm_binutils_format(lua_State *lua);
 
 #ifdef XM_CONFIG_API_HAVE_CURSES
 // register curses functions
@@ -398,7 +418,8 @@ tb_int_t xm_thread_sharedata_set(lua_State *lua);
 tb_int_t xm_thread_sharedata_get_(lua_State *lua);
 
 // open cjson
-__tb_extern_c_enter__ tb_int_t luaopen_cjson(lua_State *l);
+__tb_extern_c_enter__
+tb_int_t luaopen_cjson(lua_State *l);
 __tb_extern_c_leave__
 
 /* //////////////////////////////////////////////////////////////////////////////////////
@@ -429,6 +450,7 @@ static luaL_Reg const g_os_functions[] = {
     { "fscase", xm_os_fscase },
     { "rename", xm_os_rename },
     { "exists", xm_os_exists },
+    { "access", xm_os_access },
     { "setenv", xm_os_setenv },
     { "getenv", xm_os_getenv },
     { "getenvs", xm_os_getenvs },
@@ -463,6 +485,8 @@ static luaL_Reg const g_winos_functions[] = {
     { "registry_keys", xm_winos_registry_keys },
     { "registry_values", xm_winos_registry_values },
     { "short_path", xm_winos_short_path },
+    { "processes", xm_winos_processes },
+    { "set_error_mode", xm_winos_set_error_mode },
     { tb_null, tb_null },
 };
 #endif
@@ -479,6 +503,7 @@ static luaL_Reg const g_io_functions[] = {
     { "file_flush", xm_io_file_flush },
     { "file_isatty", xm_io_file_isatty },
     { "file_close", xm_io_file_close },
+    { "file_convert", xm_io_file_convert },
     { "file_rawfd", xm_io_file_rawfd },
     { "filelock_open", xm_io_filelock_open },
     { "filelock_lock", xm_io_filelock_lock },
@@ -578,6 +603,24 @@ static luaL_Reg const g_bloom_filter_functions[] = {
     { tb_null, tb_null },
 };
 
+// the utf8 functions
+static luaL_Reg const g_utf8_functions[] = {
+    {"char", xm_utf8_char},
+    {"byte", xm_utf8_byte},
+    {"codes", xm_utf8_codes},
+    {"codepoint", xm_utf8_codepoint},
+    {"len", xm_utf8_len},
+    {"offset", xm_utf8_offset},
+    {"sub", xm_utf8_sub},
+    {"reverse", xm_utf8_reverse},
+    {"lastof", xm_utf8_lastof},
+    {"find", xm_utf8_find},
+    {"width", xm_utf8_width},
+    {"wcwidth", xm_utf8_width},
+    {"wcswidth", xm_utf8_width},
+    {tb_null, tb_null}
+};
+
 // the string functions
 static luaL_Reg const g_string_functions[] = {
     { "trim", xm_string_trim },
@@ -586,6 +629,8 @@ static luaL_Reg const g_string_functions[] = {
     { "convert", xm_string_convert },
     { "endswith", xm_string_endswith },
     { "startswith", xm_string_startswith },
+    { "lower", xm_string_lower },
+    { "upper", xm_string_upper },
     { tb_null, tb_null },
 };
 
@@ -673,6 +718,7 @@ static luaL_Reg const g_binutils_functions[] = {
     { "rpath_list", xm_binutils_rpath_list },
     { "rpath_clean", xm_binutils_rpath_clean },
     { "extractlib", xm_binutils_extractlib },
+    { "format", xm_binutils_format },
     { tb_null, tb_null },
 };
 
@@ -715,13 +761,18 @@ static luaL_Reg const g_thread_functions[] = {
     { tb_null, tb_null },
 };
 
+// the utf8 functions
+
+
 // the lua global instance for signal handler
 static lua_State *g_lua = tb_null;
 
 // the xmake script files data
 #ifdef XM_EMBED_ENABLE
+__tb_extern_c_enter__
 extern tb_byte_t _binary_xmake_xmz_start[];
 extern tb_byte_t _binary_xmake_xmz_end[];
+__tb_extern_c_leave__
 #endif
 
 /* //////////////////////////////////////////////////////////////////////////////////////
@@ -825,7 +876,11 @@ static tb_bool_t xm_engine_get_program_file(xm_engine_t *engine, tb_char_t **arg
         ssize_t size = readlink(XM_PROC_SELF_FILE, path, (size_t)maxn);
         if (size > 0 && size < maxn) {
             path[size] = '\0';
-            ok = tb_true;
+            // ignore cosmocc ape binary, we fallback to argv[0], .e.g /usr/bin/ape, /home/ruki/.ape-1.10
+            tb_char_t const* filename = tb_strrchr(path, '/');
+            if (!tb_strstr(filename ? filename + 1 : path, "ape")) {
+                ok = tb_true;
+            }
         }
 #elif defined(TB_CONFIG_OS_BSD) && defined(KERN_PROC_PATHNAME)
         // only for FreeBSD and OpenBSD, https://github.com/xmake-io/xmake/issues/2948
@@ -868,7 +923,13 @@ static tb_bool_t xm_engine_get_program_file(xm_engine_t *engine, tb_char_t **arg
         if (!ok && argv) {
             tb_char_t const *p = argv[0];
             if (p && tb_file_info(p, tb_null)) {
-                tb_strlcpy(path, p, maxn);
+                if (tb_path_is_absolute(p)) {
+                    tb_strlcpy(path, p, maxn);
+                } else {
+                    if (!tb_path_absolute(p, path, maxn)) {
+                        tb_strlcpy(path, p, maxn);
+                    }
+                }
                 ok = tb_true;
             }
         }
@@ -1538,6 +1599,9 @@ xm_engine_ref_t xm_engine_init(tb_char_t const *name, xm_engine_lni_initalizer_c
         // bind base64 functions
         xm_lua_register(engine->lua, "base64", g_base64_functions);
 
+        // bind utf8 functions
+        xm_lua_register(engine->lua, "utf8", g_utf8_functions);
+
         // bind string functions
         xm_lua_register(engine->lua, "string", g_string_functions);
 
