@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME    "pipe_wait"
-#define TB_TRACE_MODULE_DEBUG   (0)
+#define TB_TRACE_MODULE_NAME "pipe_wait"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -35,14 +35,13 @@
  */
 
 // io.pipe_wait(pipefile, events, timeout)
-tb_int_t xm_io_pipe_wait(lua_State* lua)
-{
-    // check
+tb_int_t xm_io_pipe_wait(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // check pipe?
-    if (!xm_pipe_file_is_valid(lua, 1))
+    if (!xm_pipe_file_is_valid(lua, 1)) {
         return 0;
+    }
 
     // get pipe file
     tb_pipe_file_ref_t pipefile = xm_pipe_file_get(lua, 1);
@@ -58,4 +57,3 @@ tb_int_t xm_io_pipe_wait(lua_State* lua)
     lua_pushnumber(lua, (tb_int_t)tb_pipe_file_wait(pipefile, events, timeout));
     return 1;
 }
-
