@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "sleep"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "sleep"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,10 +33,11 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_os_sleep(lua_State* lua)
-{
+tb_int_t xm_os_sleep(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
     tb_long_t interval = (tb_long_t)luaL_checklong(lua, 1);
-    if (interval >= 0) tb_msleep(interval);
+    if (interval >= 0) {
+        tb_msleep(interval);
+    }
     return 0;
 }
