@@ -116,20 +116,18 @@ function graph:remove_vertex(v)
         end
     end)
     if contains then
-        self._edges_map[v] = nil
-        self._adjacent_edges[v] = nil
-        -- remove the adjacent edge with this vertex in the other vertices
-        for _, w in ipairs(self:vertices()) do
-            local edges = self:adjacent_edges(w)
-            if edges then
-                table.remove_if(edges, function (_, e)
-                    if e:other(w) == v then
-                        self._edges_map[w] = nil
-                        return true
-                    end
-                end)
+        -- remove all touching edges
+        local touching = {}
+        for _, e in ipairs(self._edges) do
+            if e:from() == v or e:to() == v then
+                table.insert(touching, {e:from(), e:to()})
             end
         end
+        for _, pair in ipairs(touching) do
+            self:remove_edge(pair[1], pair[2])
+        end
+        self._edges_map[v] = nil
+        self._adjacent_edges[v] = nil
 
         -- reset partial topological sort state since graph structure changed
         self._partial_topo_dirty = true
@@ -398,6 +396,59 @@ function graph:add_edge(from, to)
     self._partial_topo_dirty = true
 end
 
+-- remove edge
+function graph:remove_edge(from, to)
+    if not self:has_edge(from, to) then
+        return
+    end
+    local directed = self:is_directed()
+    local edges = self._edges
+    local target_index
+    local target_edge
+    for idx, e in ipairs(edges) do
+        local match = (e:from() == from and e:to() == to)
+        if not directed then
+            match = match or (e:from() == to and e:to() == from)
+        end
+        if match then
+            target_index = idx
+            target_edge = e
+            break
+        end
+    end
+    assert(target_edge, string.format("graph.remove_edge(%s, %s): edge not found", tostring(from), tostring(to)))
+
+    table.remove(edges, target_index)
+
+    local function remove_from_adj(vertex)
+        local adj = self._adjacent_edges[vertex]
+        if adj then
+            table.remove_if(adj, function (_, e) return e == target_edge end)
+        end
+    end
+
+    remove_from_adj(target_edge:from())
+    remove_from_adj(target_edge:to())
+
+    local edges_map = self._edges_map
+    local function clear_map(u, v)
+        local map = edges_map[u]
+        if map then
+            map[v] = nil
+            if not next(map) then
+                edges_map[u] = nil
+            end
+        end
+    end
+
+    clear_map(target_edge:from(), target_edge:to())
+    if not directed then
+        clear_map(target_edge:to(), target_edge:from())
+    end
+
+    self._partial_topo_dirty = true
+end
+
 -- has the given edge?
 function graph:has_edge(from, to)
     local edges_map = self._edges_map
@@ -413,13 +464,8 @@ end
 -- clone graph
 function graph:clone()
     local gh = graph.new(self:is_directed())
-    for _, v in ipairs(self:vertices()) do
-        local edges = self:adjacent_edges(v)
-        if edges then
-            for _, e in ipairs(edges) do
-                gh:add_edge(e:from(), e:to())
-            end
-        end
+    for _, e in ipairs(self._edges) do
+        gh:add_edge(e:from(), e:to())
     end
     return gh
 end
@@ -430,13 +476,8 @@ function graph:reverse()
         return self:clone()
     end
     local gh = graph.new(self:is_directed())
-    for _, v in ipairs(self:vertices()) do
-        local edges = self:adjacent_edges(v)
-        if edges then
-            for _, e in ipairs(edges) do
-                gh:add_edge(e:to(), e:from())
-            end
-        end
+    for _, e in ipairs(self._edges) do
+        gh:add_edge(e:to(), e:from())
     end
     return gh
 end
