@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        option.lua
@@ -30,8 +30,6 @@ local text      = require("base/text")
 
 -- translate the menu
 function option._translate(menu)
-
-    -- translate the menus if exists function
     local submenus_all = {}
     for k, submenu in pairs(menu) do
         if type(submenu) == "function" then
@@ -49,15 +47,12 @@ function option._translate(menu)
     end
     table.copy2(menu, submenus_all)
 
-    -- save menu
     option._MENU = menu
-
-    -- ok
     return true
 end
 
+-- show menu in narrow mode?
 function option._modenarrow()
-    -- show menu in narrow mode?
     local width = os.getwinsize().width
     return width > 0 and width < 60
 end
@@ -98,10 +93,6 @@ end
 
 -- init the option
 function option.init(menu)
-
-    -- check
-    assert(menu)
-
     -- translate menu
     local ok, errors = option._translate(menu)
     if not ok then
@@ -148,15 +139,11 @@ function option.init(menu)
 
     -- init the default value
     option.populate_defaults(options, context.defaults)
-
-    -- ok
     return true
 end
 
 -- parse arguments with the given options
 function option.parse(argv, options, opt)
-
-    -- check
     assert(argv and options)
     opt = opt or { populate_defaults = true }
 
@@ -275,15 +262,11 @@ function option.parse(argv, options, opt)
     if opt.populate_defaults then
         option.populate_defaults(options, results)
     end
-
-    -- ok
     return results
 end
 
 -- fill defined with option's default value, in place
 function option.populate_defaults(options, defined)
-
-    -- check
     assert(options and defined)
 
     -- populate the default value
@@ -329,35 +312,19 @@ end
 
 -- get the task menu
 function option.taskmenu(task)
-
-    -- check
     assert(option._MENU)
 
-    -- the current task
     task = task or option.taskname() or "main"
-
-    -- get the task menu
     local taskmenu = option._MENU[task]
     if type(taskmenu) == "function" then
-
-        -- load this task menu
         taskmenu = taskmenu()
-
-        -- save this task menu
         option._MENU[task] = taskmenu
     end
-
-    -- get it
     return taskmenu
 end
 
 -- get the given option value for the current task
 function option.get(name)
-
-    -- check
-    assert(name)
-
-    -- the options
     local options = option.options()
     if options then
         local value = options[name]
@@ -370,10 +337,6 @@ end
 
 -- set the given option for the current task
 function option.set(name, value)
-
-    -- check
-    assert(name)
-
     -- cannot be the first context for menu
     assert(#option._CONTEXTS > 1)
 
@@ -400,18 +363,14 @@ end
 function option.default(name)
     assert(name)
 
-    -- the defaults
     local defaults = option.defaults()
     assert(defaults)
 
-    -- get it
     return defaults[name]
 end
 
 -- get the current options
 function option.options()
-
-    -- get it
     local context = option._context()
     if context then
         return context.options
@@ -480,7 +439,7 @@ function option.show_logo(logo, opt)
     /_/\_\_|_|  |_|\__ \|_|\_\____|
 
                          by ruki, xmake.io
-    ]]
+]]
 
     -- make rainbow for logo
     opt = opt or {}
@@ -505,9 +464,9 @@ function option.show_logo(logo, opt)
 
     -- define footer
     local footer = [[
-    ${point_right}  ${bright}Manual${clear}: ${underline}https://xmake.io/#/getting_started${clear}
-    ${pray}  ${bright}Donate${clear}: ${underline}https://xmake.io/#/sponsor${clear}
-    ]]
+    ${point_right}  ${bright}Manual${clear}: ${underline}https://xmake.io/guide/quick-start${clear}
+    ${pray}  ${bright}Donate${clear}: ${underline}https://xmake.io/about/sponsor${clear}
+]]
 
     -- show footer
     io.print(colors.translate(footer))
