@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        install_package.lua
@@ -25,8 +25,11 @@ import("core.project.config")
 import("core.tool.toolchain")
 import("core.platform.platform")
 import("lib.detect.find_tool")
+import("lib.detect.find_file")
+import("detect.sdks.find_emsdk")
 import("devel.git")
 import("net.fasturl")
+import("package.manager.conan.configurations")
 
 -- get build env
 function _conan_get_build_env(name, plat)
@@ -46,7 +49,7 @@ end
 
 -- get build directory
 function _conan_get_build_directory(name)
-    return path.absolute(path.join(config.buildir() or os.tmpdir(), ".conan", name))
+    return path.absolute(path.join(config.builddir() or os.tmpdir(), ".conan", name))
 end
 
 -- generate conanfile.txt
@@ -110,45 +113,6 @@ function _conan_install_xmake_generator(conan)
     end
 end
 
--- get arch
-function _conan_get_arch(arch)
-    local map = {x86_64          = "x86_64",
-                 x64             = "x86_64",
-                 i386            = "x86",
-                 x86             = "x86",
-                 armv7           = "armv7",
-                 ["armv7-a"]     = "armv7",  -- for android, deprecated
-                 ["armeabi"]     = "armv7",  -- for android, removed in ndk r17
-                 ["armeabi-v7a"] = "armv7",  -- for android
-                 armv7s          = "armv7s", -- for iphoneos
-                 arm64           = "armv8",  -- for iphoneos
-                 ["arm64-v8a"]   = "armv8",  -- for android
-                 mips            = "mips",
-                 mips64          = "mips64"}
-    return assert(map[arch], "unknown arch(%s)!", arch)
-end
-
--- get os
-function _conan_get_os(plat)
-    local map = {macosx   = "Macos",
-                 windows  = "Windows",
-                 mingw    = "Windows",
-                 linux    = "Linux",
-                 cross    = "Linux",
-                 iphoneos = "iOS",
-                 android  = "Android"}
-    return assert(map[plat], "unknown os(%s)!", plat)
-end
-
--- get build type
-function _conan_get_build_type(mode)
-    if mode == "debug" then
-        return "Debug"
-    else
-        return "Release"
-    end
-end
-
 -- get compiler version
 --
 -- https://github.com/conan-io/conan/blob/353c63b16c31c90d370305b5cbb5dc175cf8a443/conan/tools/microsoft/visual.py#L13
@@ -229,6 +193,20 @@ function _conan_generate_compiler_profile(profile, configs, opt)
         end
         conf = {}
         conf["tools.android:ndk_path"] = ndk:config("ndk")
+    elseif plat == "wasm" then
+        local emsdk = find_emsdk()
+        assert(emsdk and emsdk.emscripten, "emscripten not found!")
+        local emscripten_cmakefile = find_file("Emscripten.cmake", path.join(emsdk.emscripten, "cmake/Modules/Platform"))
+        assert(emscripten_cmakefile, "Emscripten.cmake not found!")
+
+        profile:print("compiler=gcc")
+        profile:print("compiler.cppstd=gnu17")
+        profile:print("compiler.libcxx=libstdc++11")
+        profile:print("compiler.version=12")
+
+        conf = {}
+        conf["tools.build:compiler_executables"] = "{'c':'emcc', 'cpp':'em++', 'ar':'emar', 'ranlib':'emranlib'}"
+        conf["tools.cmake.cmaketoolchain:user_toolchain"] = "['" ..emscripten_cmakefile .. "']"
     else
         local program, toolname = platform.tool("cc", plat, arch)
         if toolname == "gcc" or toolname == "clang" then
@@ -261,9 +239,9 @@ end
 function _conan_generate_build_profile(configs, opt)
     local profile = io.open("profile_build.txt", "w")
     profile:print("[settings]")
-    profile:print("arch=%s", _conan_get_arch(os.arch()))
-    profile:print("build_type=%s", _conan_get_build_type(opt.mode))
-    profile:print("os=%s", _conan_get_os(os.host()))
+    profile:print("arch=%s", configurations.arch(os.arch()))
+    profile:print("build_type=%s", configurations.build_type(opt.mode))
+    profile:print("os=%s", configurations.plat(os.host()))
     _conan_generate_compiler_profile(profile, configs, {plat = os.host(), arch = os.arch()})
     profile:close()
 end
@@ -272,9 +250,9 @@ end
 function _conan_generate_host_profile(configs, opt)
     local profile = io.open("profile_host.txt", "w")
     profile:print("[settings]")
-    profile:print("arch=%s", _conan_get_arch(opt.arch))
-    profile:print("build_type=%s", _conan_get_build_type(opt.mode))
-    profile:print("os=%s", _conan_get_os(opt.plat))
+    profile:print("arch=%s", configurations.arch(opt.arch))
+    profile:print("build_type=%s", configurations.build_type(opt.mode))
+    profile:print("os=%s", configurations.plat(opt.plat))
     _conan_generate_compiler_profile(profile, configs, opt)
     profile:close()
 end
@@ -287,16 +265,16 @@ function main(conan, name, opt)
     local configs = opt.configs or {}
 
     -- get build directory
-    local buildir = _conan_get_build_directory(name)
+    local builddir = _conan_get_build_directory(name)
 
     -- clean the build directory
-    os.tryrm(buildir)
-    if not os.isdir(buildir) then
-        os.mkdir(buildir)
+    os.tryrm(builddir)
+    if not os.isdir(builddir) then
+        os.mkdir(builddir)
     end
 
     -- enter build directory
-    local oldir = os.cd(buildir)
+    local oldir = os.cd(builddir)
 
     -- install xmake generator
     _conan_install_xmake_generator(conan)
@@ -333,6 +311,18 @@ function main(conan, name, opt)
         table.insert(argv, setting)
     end
 
+    -- set custom host configurations
+    for _, conf in ipairs(configs.conf or configs.conf_host) do
+        table.insert(argv, "-c")
+        table.insert(argv, conf)
+    end
+
+    -- set custom build configurations
+    for _, conf in ipairs(configs.conf_build) do
+        table.insert(argv, "-c:b")
+        table.insert(argv, conf)
+    end
+
     -- set remote
     if configs.remote then
         table.insert(argv, "-r")
