@@ -342,24 +342,13 @@ function _add_package_configurations(package)
     package:add("configs", "shflags", {builtin = true, description = "Set the shared library linker flags."})
 end
 
--- select package version
-function _select_package_version(package, requireinfo, locked_requireinfo)
+-- select version from scheme
+function _select_version_from_scheme(scheme, requireinfo)
 
-    -- get it from the locked requireinfo
-    if locked_requireinfo then
-        local version = locked_requireinfo.version
-        local source = "version"
-        if locked_requireinfo.branch then
-            source = "branch"
-        elseif locked_requireinfo.tag then
-            source = "tag"
-        end
-        return version, source
-    end
-
-    -- has git url?
+    -- check urls
+    local urls = scheme:urls()
     local has_giturl = false
-    for _, url in ipairs(package:urls()) do
+    for _, url in ipairs(urls) do
         if git.checkurl(url) then
             has_giturl = true
             break
@@ -372,8 +361,9 @@ function _select_package_version(package, requireinfo, locked_requireinfo)
     local require_version = requireinfo.version
     local require_verify  = requireinfo.verify
     local is_system = requireinfo.system
-    local has_versionlist = package:get("versions") or package:get("versionfiles")
-    if (not has_versionlist or require_verify == false)
+    local has_versionlist = scheme:get("versions") or scheme:get("versionfiles")
+    -- We need to strictly limit the number of valid URLs to filter out schemes that don't have any URLs, prioritizing them.
+    if #urls > 0 and (not has_versionlist or require_verify == false)
         and (semver.is_valid(require_version) or semver.is_valid_range(require_version)) then
         -- no version list in package() or need not verify sha256sum? try selecting this version directly
         -- @see
@@ -382,8 +372,8 @@ function _select_package_version(package, requireinfo, locked_requireinfo)
         -- https://github.com/xmake-io/xmake/issues/3551
         version = require_version
         source = "version"
-    elseif #package:versions() > 0 then -- select version?
-        version, source = try { function () return semver.select(require_version, package:versions()) end }
+    elseif #scheme:versions() > 0 then -- select version?
+        version, source = try { function () return semver.select(require_version, scheme:versions()) end }
     end
     if not version and has_giturl then -- select branch?
         if require_version and #require_version == 40 and require_version:match("%w+") then
@@ -393,11 +383,85 @@ function _select_package_version(package, requireinfo, locked_requireinfo)
         end
     end
     -- local source package? we use a phony version
-    if not version and require_version == "latest" and #package:urls() == 0 then
+    if not version and require_version == "latest" and #urls == 0 then
         version = "latest"
         source = "version"
     end
+    return version, source
+end
+
+-- select package version
+function _select_package_version(package, requireinfo, locked_requireinfo)
+
+    -- get it from the locked requireinfo
+    if locked_requireinfo then
+        local version = locked_requireinfo.version
+        local source = "version"
+        if locked_requireinfo.branch then
+            source = "branch"
+        elseif locked_requireinfo.tag then
+            source = "tag"
+        end
+        package:version_set(version, source)
+        return version, source
+    end
+
+    -- select version from schemes
+    local version, source
+    local version_latest, source_latest
+    local scheme_version_map = {}
+    for _, scheme in ipairs(package:schemes_orderlist()) do
+        local scheme_version, scheme_source = _select_version_from_scheme(scheme, requireinfo)
+        if scheme_version then
+            scheme_version_map[scheme] = scheme_version
+            scheme:version_set(scheme_version, scheme_source)
+            if not version and scheme_version ~= "latest" then
+                version = scheme_version
+                source = scheme_source
+            end
+            if not version_latest and scheme_version == "latest" then
+                version_latest = scheme_version
+                source_latest = scheme_source
+            end
+        end
+    end
+    if not version then
+        -- If no version is available for any scheme and no URLs are available, we will use the specified version by default.
+        -- https://github.com/xmake-io/xmake/issues/7265
+        local require_version = requireinfo.version
+        local require_verify  = requireinfo.verify
+        local current_scheme = package:current_scheme()
+        local has_versionlist = current_scheme:get("versions") or current_scheme:get("versionfiles")
+        if (not has_versionlist or require_verify == false)
+            and (semver.is_valid(require_version) or semver.is_valid_range(require_version)) then
+            local scheme_version = require_version
+            local scheme_source = "version"
+            scheme_version_map[current_scheme] = scheme_version
+            current_scheme:version_set(scheme_version, scheme_source)
+            version = scheme_version
+            source = scheme_source
+        end
+    end
+    if not version then
+        version = version_latest
+        source = source_latest
+    end
+
+    -- remove these invalid schemes if version is not matched
+    table.remove_if(package:schemes_orderlist(), function (_, scheme)
+        local scheme_version = scheme_version_map[scheme]
+        if not scheme_version or (version and scheme_version ~= version) then
+            package:schemes()[scheme:name()] = nil
+            -- reset current scheme cache, we need to resolve new current scheme
+            package:current_scheme_set(nil)
+            return true
+        end
+    end)
+    assert(#package:schemes_orderlist() > 0, "package(%s): no available schemes with urls and versions", package:name())
+
+    local is_system = requireinfo.system
     if not version and not package:is_thirdparty() and is_system ~= true then
+        local require_version = requireinfo.version
         raise("package(%s): version(%s) not found!", package:name(), require_version)
     end
     return version, source
@@ -546,7 +610,8 @@ function _finish_requireinfo(requireinfo, package)
         else
             runtimes = {}
         end
-        if not table.contains(runtimes, "MT", "MD", "MTd", "MDd") then
+        -- we should not set default runtimes if runtimes has been set, e.g. `xmake f --toolchain=clang --runtimes=c++_shared`
+        if #runtimes == 0 then
             local vs_runtime_default = project.policy("build.c++.msvc.runtime")
             if vs_runtime_default and is_mode("debug") then
                 vs_runtime_default = vs_runtime_default .. "d"
@@ -792,7 +857,7 @@ function _select_artifacts(package, artifacts_manifest)
         artifacts_info = _select_artifacts_for_generic(package, artifacts_manifest)
     end
     if artifacts_info then
-        package:artifacts_set(artifacts_info)
+        package:use_precompiled_artifacts(artifacts_info)
     end
 end
 
@@ -801,7 +866,8 @@ function _select_package_runtimes(package)
     local runtimes = package:config("runtimes")
     if runtimes then
         local runtimes_supported = hashset.new()
-        local toolchains = package:toolchains() or platform.load(package:plat(), package:arch()):toolchains()
+        local toolchains = package:toolchains() or
+            platform.load(package:plat(), package:arch(), {host = package:is_host()}):toolchains()
         if toolchains then
             for _, toolchain_inst in ipairs(toolchains) do
                 if toolchain_inst:is_standalone() and toolchain_inst:get("runtimes") then
@@ -909,7 +975,11 @@ function _load_package(packagename, requireinfo, opt)
         local tips
         local possible_package = get_possible_package(packagename)
         if possible_package then
-            tips = string.format(", maybe ${bright}%s %s${clear} in %s", possible_package.name, possible_package.version, possible_package.reponame)
+            local possible_name = possible_package.name
+            if possible_package.version then
+                possible_name = possible_name .. " " .. possible_package.version
+            end
+            tips = string.format(", maybe ${bright}%s${clear} in %s", possible_name, possible_package.reponame)
         end
         cprint("  -> %s%s", packagename, tips or "")
         raise("package(%s) not found!", packagename)
@@ -945,7 +1015,6 @@ function _load_package(packagename, requireinfo, opt)
     -- select package version
     local version, source = _select_package_version(package, requireinfo, locked_requireinfo)
     if version then
-        package:version_set(version, source)
         package:data_set("__locked_requireinfo", locked_requireinfo)
     end
 
@@ -1024,14 +1093,7 @@ function _load_package(packagename, requireinfo, opt)
     -- do load
     package:_load()
 
-    -- load all components
-    for _, component in pairs(package:components()) do
-        component:_load()
-    end
-
-    -- load environments from the manifest to enable the environments of on_install()
-    package:envs_load()
-
+    -- check api
     check_api(package, {load = true})
 
     -- save this package package to cache
