@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        action.lua
@@ -29,5 +29,5 @@ end
 
 function main()
     config.load()
-    remote_build_client.singleton():runcmd(os.programfile(), xmake.argv())
+    remote_build_client.singleton():runcmd("xmake", xmake.argv())
 end
