@@ -295,15 +295,20 @@ function script_extension_module_apis()
                 if path.filename(modulename) == "main.lua" then
                     modulename = path.directory(modulename)
                 end
-                modulename = modulename:gsub("[\\/]", "."):gsub("%.lua", "")
-                local instance = import(modulename, {try = true, anonymous = true})
-                if instance then
-                    if _is_callable(instance) then
-                        table.insert(result, modulename)
-                    elseif type(instance) == "table" then
-                        for k, v in pairs(instance) do
-                            if not k:startswith("_") and type(v) == "function" then
-                                table.insert(result, modulename .. "." .. k)
+                modulename = modulename:gsub("[\\/]", "."):gsub("%.lua$", "")
+                -- skip luajit modules in non-luajit runtime
+                if not xmake.luajit() and modulename:find("luajit%.") then
+                    -- skip this module
+                else
+                    local instance = import(modulename, {try = true, anonymous = true})
+                    if instance then
+                        if _is_callable(instance) then
+                            table.insert(result, modulename)
+                        elseif type(instance) == "table" then
+                            for k, v in pairs(instance) do
+                                if not k:startswith("_") and type(v) == "function" then
+                                    table.insert(result, modulename .. "." .. k)
+                                end
                             end
                         end
                     end
