@@ -168,9 +168,6 @@ function _get_std_module_manifest_path(target)
 end
 
 function get_stdmodules(target)
-    if not target:policy("build.c++.modules.std") then
-        return
-    end
     local modules_json_path = _get_std_module_manifest_path(target)
     if modules_json_path then
         local modules_json = json.loadfile(modules_json_path)
@@ -314,7 +311,8 @@ function get_cppversionflag(target)
     if cppversionflag == nil then
         local compinst = target:compiler("cxx")
         local flags = compinst:compflags({target = target})
-        cppversionflag = table.find_if(flags, function(v) string.startswith(v, "-std=c++") end) or "-std=c++20"
+        local idx = table.find_first_if(flags, function(_, v) return string.startswith(v, "-std=c++") end)
+        cppversionflag = (idx and flags[idx]) or "-std=c++20"
         _g.cppversionflag = cppversionflag
     end
     return cppversionflag or nil
