@@ -22,31 +22,7 @@
 import("core.base.option")
 import("core.base.semver")
 import("core.project.config")
-import("detect.sdks.find_vstudio")
-
--- add the given vs environment
-function _add_vsenv(toolchain, name, curenvs)
-
-    -- get vcvars
-    local vcvars = toolchain:config("vcvars")
-    if not vcvars then
-        return
-    end
-
-    -- get the paths for the vs environment
-    local new = vcvars[name]
-    if new then
-        -- fix case naming conflict for cmake/msbuild between the new msvc envs and current environment, if we are running xmake in vs prompt.
-        -- @see https://github.com/xmake-io/xmake/issues/4751
-        for k, c in pairs(curenvs) do
-            if name:lower() == k:lower() and name ~= k then
-                name = k
-                break
-            end
-        end
-        toolchain:add("runenvs", name, table.unwrap(path.splitenv(new)))
-    end
-end
+import("private.utils.toolchain", {alias = "toolchain_utils"})
 
 -- main entry
 function main(toolchain)
@@ -74,16 +50,7 @@ function main(toolchain)
     end
 
     -- add vs environments
-    local expect_vars = {"PATH", "LIB", "INCLUDE", "LIBPATH"}
-    local curenvs = os.getenvs()
-    for _, name in ipairs(expect_vars) do
-        _add_vsenv(toolchain, name, curenvs)
-    end
-    for _, name in ipairs(find_vstudio.get_vcvars()) do
-        if not table.contains(expect_vars, name:upper()) then
-            _add_vsenv(toolchain, name, curenvs)
-        end
-    end
+    toolchain_utils.add_vsenvs(toolchain)
 
     -- check and add vs_binary_output env
     local vs = toolchain:config("vs")
